# 0.0.8 (2022-05-18)

### Added

- Tests

### Removed

- `requirements.txt` as the package should rely as much as possible on the Python Standard Library
- `nbresult_checker` as it has a dependency with an internal package

# 0.0.6 (2022-05-17)

### Added

- Allow specify a `subdir` folder in which store/read pickle file


# 0.0.5 (2022-02-07)

### Added

- Adds `nbresult_checker` script listing pickle files containing complex python data types
